@@ -3,42 +3,42 @@ HCPC <- function (res, nb.clust = 0, consol = TRUE, iter.max = 10, min = 3,
     graph.scale = "inertia", nb.par = 5, graph = TRUE, proba = 0.05,cluster.CA="rows",
     kk=Inf,description=TRUE,...) 
 {
-    auto.cut.tree = function(res, min, max, metric, method, weight=NULL,cla=NULL,...) {
+    auto.cut.tree <- function(res, min, max, metric, method, weight=NULL,cla=NULL,...) {
         if (order) {
-		    if (is.null(res$call$row.w)) res$call$row.w = rep(1/nrow(res$ind$coord),nrow(res$ind$coord))
+		    if (is.null(res$call$row.w)) res$call$row.w <- rep(1/nrow(res$ind$coord),nrow(res$ind$coord))
             if (is.null(res$call$row.w.init)) res$call$row.w.init <- res$call$row.w
-            sss = cbind.data.frame(res$ind$coord, res$call$X, res$call$row.w, res$call$row.w.init)
+            sss <- cbind.data.frame(res$ind$coord, res$call$X, res$call$row.w, res$call$row.w.init)
 			if (!is.null(weight)) weight <- weight[order(sss[, 1], decreasing = FALSE)]
-            sss = sss[order(sss[, 1], decreasing = FALSE), ]
-            res$ind$coord = sss[, 1:ncol(res$ind$coord),drop=FALSE]
-            res$call$X = sss[, (ncol(res$ind$coord) + 1):(ncol(sss)-2)]
-            res$call$row.w = sss[,ncol(sss)-1]
-            res$call$row.w.init = sss[,ncol(sss)]
+            sss <- sss[order(sss[, 1], decreasing = FALSE), ]
+            res$ind$coord <- sss[, 1:ncol(res$ind$coord),drop=FALSE]
+            res$call$X <- sss[, (ncol(res$ind$coord) + 1):(ncol(sss)-2)]
+            res$call$row.w <- sss[,ncol(sss)-1]
+            res$call$row.w.init <- sss[,ncol(sss)]
         }
-        X = as.data.frame(res$ind$coord)	
+        X <- as.data.frame(res$ind$coord)	
 
 #		if("flashClust"%in%rownames(installed.packages())) require(flashClust,quiet=TRUE)
         do <- dist(X,method=metric)^2
-        if (is.null(weight)) weight=rep(1,nrow(X))
+        if (is.null(weight)) weight <- rep(1,nrow(X))
         eff <- outer(weight,weight,FUN=function(x,y,n) {x*y/n/(x+y)},n=sum(weight))
         dissi <- do*eff[lower.tri(eff)]
         hc <- flashClust::hclust(dissi, method = method, members = weight)
 		inert.gain <- rev(hc$height)
 		if (!is.null(cla)) inert.gain <- c(inert.gain,cla$tot.withinss/sum(cla$size))
 		intra <- rev(cumsum(rev(inert.gain)))
-        quot = intra[min:(max)]/intra[(min - 1):(max - 1)] 
-		nb.clust = which.min(quot) + min -1
+        quot <- intra[min:(max)]/intra[(min - 1):(max - 1)] 
+		nb.clust <- which.min(quot) + min -1
 # changement dans calcul annule. Mis dans la version 1.34  2016/04/12 (2 lignes changees)
 #        quot = inert.gain[(min-1):(max-1)]/inert.gain[min:max] 
 #		nb.clust = which.max(quot) + min - 1
         return(list(res = res, tree = hc, nb.clust = nb.clust, 
             within = intra, inert.gain = inert.gain, quot = quot))
     }
-    consolidation = function(X, clust, iter.max = 10, ...) {
-        centers = NULL
-        centers = by(X, clust, colMeans)
-        centers = matrix(unlist(centers), ncol = ncol(X), byrow = TRUE)
-        km = kmeans(X, centers = centers, iter.max = iter.max, ...)
+    consolidation <- function(X, clust, iter.max = 10, ...) {
+        centers <- NULL
+        centers <- by(X, clust, colMeans)
+        centers <- matrix(unlist(centers), ncol = ncol(X), byrow = TRUE)
+        km <- kmeans(X, centers = centers, iter.max = iter.max, ...)
         return(km)
     }
     select <- function(Y, default.size, method, coord.centers) {
@@ -59,7 +59,7 @@ HCPC <- function (res, nb.clust = 0, consol = TRUE, iter.max = 10, min = 3,
             distance <- distance[1:default.size]
         else distance <- distance
     }
-    distinctivness = function(Y, default.size, method, coord.centers) {
+    distinctivness <- function(Y, default.size, method, coord.centers) {
         clust <- as.numeric(Y[1, ncol(Y)])
         Y <- Y[, -ncol(Y),drop=FALSE]
         Z <- rbind(Y, coord.centers)
@@ -76,15 +76,15 @@ HCPC <- function (res, nb.clust = 0, consol = TRUE, iter.max = 10, min = 3,
             else center.min <- apply(distance[-clust, ], 2, min)
             ind.car <- sort(center.min, decreasing = TRUE)
         }
-        if (length(ind.car) > default.size) ind.car = ind.car[1:default.size]
-        else ind.car = ind.car
+        if (length(ind.car) > default.size) ind.car <- ind.car[1:default.size]
+        else ind.car <- ind.car
     }
 #### Main program
 #   if((method=="ward")&(!("flashClust"%in%rownames(installed.packages())))) method="ward.D" ### use of ward.D because I transform the distance to have the results obtained by ward.D2 
    res.sauv <- res	
    if ((kk!=Inf)&(consol==TRUE)){
      warning("No consolidation has been done after the hierarchical clustering since kk is different from Inf (see help for more details)")
-     consol=FALSE
+     consol <- FALSE
    }
    if (is.vector(res)) {
         res <- cbind.data.frame(res, res)
@@ -160,7 +160,7 @@ HCPC <- function (res, nb.clust = 0, consol = TRUE, iter.max = 10, min = 3,
             if (!nzchar(Sys.getenv("RSTUDIO_USER_IDENTITY"))) dev.new()
             old.mar <- par()$mar
             par(mar = c(0.5, 2, 0.75, 0))
-            lay = matrix(ncol = 5, nrow = 5, c(2, 4, 4, 4, 4, 
+            lay <- matrix(ncol = 5, nrow = 5, c(2, 4, 4, 4, 4, 
                 2, 4, 4, 4, 4, 2, 4, 4, 4, 4, 2, 4, 4, 4, 4, 
                 1, 3, 3, 3, 3))
             layout(lay, respect = TRUE)
@@ -195,15 +195,15 @@ HCPC <- function (res, nb.clust = 0, consol = TRUE, iter.max = 10, min = 3,
         } else {
             if (graph)
                 plot(t$tree, hang = -1, main = "Hierarchical Classification", xlab = "", sub = "")
-            if (nb.clust < 0) y = auto.haut
-            else y = (t$tree$height[length(t$tree$height) - nb.clust + 2] + t$tree$height[length(t$tree$height) - nb.clust + 1])/2
+            if (nb.clust < 0) y <- auto.haut
+            else y <- (t$tree$height[length(t$tree$height) - nb.clust + 2] + t$tree$height[length(t$tree$height) - nb.clust + 1])/2
         }
     }
     else stop("The tree should be from 'hclust' or 'agnes' class.")
     clust <- cutree(as.hclust(t$tree), h = y)
     nb.clust <- max(clust)
-	X = as.data.frame(t$res$ind$coord)
-	ordColo = unique(clust[t$tree$order])
+	X <- as.data.frame(t$res$ind$coord)
+	ordColo <- unique(clust[t$tree$order])
 
     if (graph) {
 #    if ((graph)&!nzchar(Sys.getenv("RSTUDIO_USER_IDENTITY"))) {
@@ -242,12 +242,12 @@ names(rr) <- names(cla$cluster)
 cla$cluster <- as.factor(rr)
 }
 ## fin ajout			
-centers = res.consol$centers
+centers <- res.consol$centers
     }
     if (!consol) {
         list.centers <- by(X, clust, colMeans)
         centers <- matrix(unlist(list.centers), ncol = ncol(X),byrow = TRUE)
-        colnames(centers) = colnames(X)
+        colnames(centers) <- colnames(X)
 
 		## ajout pour trier les classes
 		aux <- names(clust) <- rownames(X)
@@ -303,7 +303,8 @@ if (kk<Inf){
   if (vec) data.clust <- as.data.frame(data.clust[, -2])
 if (description){
      if (!inherits(res.sauv, "CA")&!(vec)){
-	   desc.var <- catdes(data.clust, ncol(data.clust), proba = proba, row.w = res.sauv$call$row.w.init)
+	   if (!is.null(res.sauv$call$row.w.init)) desc.var <- catdes(data.clust, ncol(data.clust), proba = proba, row.w = res.sauv$call$row.w.init)
+	   else desc.var <- catdes(data.clust, ncol(data.clust), proba = proba, row.w = res.sauv$call$row.w)
 	 }
     else {
       if ((vec) | (is.null(res.sauv$call$quanti.sup)& is.null(res.sauv$call$quali.sup))) desc.var <- descfreq(data.clust[,-which(sapply(data.clust,is.factor))], data.clust[,ncol(data.clust)], proba = proba)
@@ -321,12 +322,12 @@ if (description){
 #  if (inherits(res.sauv, "CA")&(cluster.CA=="columns")) tabInd <- cbind.data.frame(res.sauv$col$coord,data.clust[,ncol(data.clust)])
   if (inherits(res.sauv, "CA")&(cluster.CA=="rows")) tabInd <- cbind.data.frame(res.sauv$row$coord,data.clust[rownames(res.sauv$row$coord),ncol(data.clust)])
   if (inherits(res.sauv, "CA")&(cluster.CA=="columns")) tabInd <- cbind.data.frame(res.sauv$col$coord,data.clust[rownames(res.sauv$col$coord),ncol(data.clust)])
-colnames(tabInd)[ncol(tabInd)]="Cluster"
+colnames(tabInd)[ncol(tabInd)] <- "Cluster"
 
 if (description){
   list.centers <- by(tabInd[,-ncol(tabInd),drop=FALSE], tabInd[,ncol(tabInd)], colMeans)
   centers <- matrix(unlist(list.centers), ncol = ncol(tabInd)-1,byrow = TRUE)
-  colnames(centers) = colnames(tabInd)[-ncol(tabInd)]
+  colnames(centers) <- colnames(tabInd)[-ncol(tabInd)]
   cluster <- tabInd[,ncol(tabInd),drop=FALSE]
   para <- by(tabInd, cluster, simplify = FALSE, select, default.size = nb.par, method = metric, coord.centers = centers)
   dist <- by(tabInd, cluster, simplify = FALSE, distinctivness, default.size = nb.par, method = metric, coord.centers = centers)
@@ -358,6 +359,6 @@ if (description){
 			legend("topleft",legend = paste("Cluster",1:nlevels(data.clust$clust)),text.col=1:nlevels(data.clust$clust),cex=0.8)
 	}
     if (graph) par(mar = old.mar)
-    class(res.HCPC) = "HCPC"
+    class(res.HCPC) <- "HCPC"
     return(res.HCPC)
 }
